@@ -34,7 +34,7 @@
 //BEGIN Kolf::Bumper
 
 Kolf::Bumper::Bumper(QGraphicsItem* parent, b2World* world)
-	: EllipticalCanvasItem(false, QLatin1String("bumper_off"), parent, world)
+	: EllipticalCanvasItem(false, QStringLiteral("bumper_off"), parent, world)
 {
 	const int diameter = 20;
 	setSize(QSizeF(diameter, diameter));
@@ -57,14 +57,16 @@ bool Kolf::Bumper::collision(Ball* ball)
 	ball->setVelocity(betweenVector);
 	ball->setState(Rolling);
 
-	setSpriteKey(QLatin1String("bumper_on"));
-	QTimer::singleShot(100, this, SLOT(turnBumperOff()));
+	game->playSound(Sound::Bumper);
+
+	setSpriteKey(QStringLiteral("bumper_on"));
+	QTimer::singleShot(100, this, &Kolf::Bumper::turnBumperOff);
 	return true;
 }
 
 void Kolf::Bumper::turnBumperOff()
 {
-	setSpriteKey(QLatin1String("bumper_off"));
+	setSpriteKey(QStringLiteral("bumper_off"));
 }
 
 Kolf::Overlay* Kolf::Bumper::createOverlay()
@@ -141,8 +143,8 @@ Kolf::WallOverlay::WallOverlay(Kolf::Wall* wall)
 {
 	addHandle(m_handle1);
 	addHandle(m_handle2);
-	connect(m_handle1, SIGNAL(moveRequest(QPointF)), this, SLOT(moveHandle(QPointF)));
-	connect(m_handle2, SIGNAL(moveRequest(QPointF)), this, SLOT(moveHandle(QPointF)));
+	connect(m_handle1, &Kolf::OverlayHandle::moveRequest, this, &Kolf::WallOverlay::moveHandle);
+	connect(m_handle2, &Kolf::OverlayHandle::moveRequest, this, &Kolf::WallOverlay::moveHandle);
 }
 
 void Kolf::WallOverlay::update()
@@ -195,7 +197,7 @@ Kolf::RectangleItem::RectangleItem(const QString& type, QGraphicsItem* parent, b
 	addShape(m_shape);
 	setSimulationType(CanvasItem::NoSimulation);
 	//default size
-	setSize(type == "sign" ? QSize(110, 40) : QSize(80, 40));
+	setSize(type == QLatin1String("sign") ? QSize(110, 40) : QSize(80, 40));
 }
 
 Kolf::RectangleItem::~RectangleItem()
@@ -360,7 +362,7 @@ Kolf::RectangleOverlay::RectangleOverlay(Kolf::RectangleItem* item)
 		Kolf::OverlayHandle* handle = new Kolf::OverlayHandle(Kolf::OverlayHandle::CircleShape, this);
 		m_handles << handle;
 		addHandle(handle);
-		connect(handle, SIGNAL(moveRequest(QPointF)), this, SLOT(moveHandle(QPointF)));
+		connect(handle, &Kolf::OverlayHandle::moveRequest, this, &Kolf::RectangleOverlay::moveHandle);
 	}
 }
 
@@ -409,9 +411,9 @@ Kolf::RectangleConfig::RectangleConfig(Kolf::RectangleItem* item, QWidget* paren
 		QCheckBox* checkBox = m_wallCheckBoxes[i] = new QCheckBox(i18n(captions[i]), this);
 		checkBox->setEnabled(item->isWallAllowed((Kolf::WallIndex) i));
 		checkBox->setChecked(item->hasWall((Kolf::WallIndex) i));
-		connect(checkBox, SIGNAL(toggled(bool)), SLOT(setWall(bool)));
+		connect(checkBox, &QCheckBox::toggled, this, &Kolf::RectangleConfig::setWall);
 	}
-	connect(item, SIGNAL(wallChanged(Kolf::WallIndex,bool,bool)), SLOT(wallChanged(Kolf::WallIndex,bool,bool)));
+	connect(item, &Kolf::RectangleItem::wallChanged, this, &Kolf::RectangleConfig::wallChanged);
 	m_layout->addWidget(new QLabel(i18n("Walls on:")), 0, 0);
 	m_layout->addWidget(m_wallCheckBoxes[0], 0, 1);
 	m_layout->addWidget(m_wallCheckBoxes[1], 1, 0);
@@ -425,7 +427,7 @@ Kolf::RectangleConfig::RectangleConfig(Kolf::RectangleItem* item, QWidget* paren
 		m_layout->addWidget(new QLabel(i18n("Sign HTML:")), 3, 0, 1, 3);
 		KLineEdit* edit = new KLineEdit(sign->text(), this);
 		m_layout->addWidget(edit, 4, 0, 1, 3);
-		connect(edit, SIGNAL(textChanged(QString)), sign, SLOT(setText(QString)));
+		connect(edit, &KLineEdit::textChanged, sign, &Kolf::Sign::setText);
 	}
 	//Kolf::Windmill does not have a special Config class
 	Kolf::Windmill* windmill = qobject_cast<Kolf::Windmill*>(item);
@@ -434,7 +436,7 @@ Kolf::RectangleConfig::RectangleConfig(Kolf::RectangleItem* item, QWidget* paren
 		QCheckBox* checkBox = new QCheckBox(i18n("Windmill on top"), this);
 		m_layout->addWidget(checkBox, 4, 0, 1, 3);
 		checkBox->setChecked(windmill->guardAtTop());
-		connect(checkBox, SIGNAL(toggled(bool)), windmill, SLOT(setGuardAtTop(bool)));
+		connect(checkBox, &QCheckBox::toggled, windmill, &Kolf::Windmill::setGuardAtTop);
 		QHBoxLayout* hlayout = new QHBoxLayout;
 		m_layout->addLayout(hlayout, 5, 0, 1, 3);
 		QLabel* label1 = new QLabel(i18n("Slow"), this);
@@ -446,7 +448,7 @@ Kolf::RectangleConfig::RectangleConfig(Kolf::RectangleItem* item, QWidget* paren
 		slider->setRange(1, 10);
 		slider->setPageStep(1);
 		slider->setValue(windmill->speed());
-		connect(slider, SIGNAL(valueChanged(int)), windmill, SLOT(setSpeed(int)));
+		connect(slider, &QSlider::valueChanged, windmill, &Kolf::Windmill::setSpeed);
 	}
 	//Kolf::Floater does not have a special Config class
 	Kolf::Floater* floater = qobject_cast<Kolf::Floater*>(item);
@@ -464,7 +466,7 @@ Kolf::RectangleConfig::RectangleConfig(Kolf::RectangleItem* item, QWidget* paren
 		slider->setRange(0, 20);
 		slider->setPageStep(2);
 		slider->setValue(floater->speed());
-		connect(slider, SIGNAL(valueChanged(int)), floater, SLOT(setSpeed(int)));
+		connect(slider, &QSlider::valueChanged, floater, &Kolf::Floater::setSpeed);
 	}
 }
 
@@ -488,7 +490,7 @@ void Kolf::RectangleConfig::wallChanged(Kolf::WallIndex index, bool hasWall, boo
 //BEGIN Kolf::Bridge
 
 Kolf::Bridge::Bridge(QGraphicsItem* parent, b2World* world)
-	: Kolf::RectangleItem(QLatin1String("bridge"), parent, world)
+	: Kolf::RectangleItem(QStringLiteral("bridge"), parent, world)
 {
 	setZBehavior(CanvasItem::IsStrut, 0);
 }
@@ -503,7 +505,7 @@ bool Kolf::Bridge::collision(Ball* ball)
 //BEGIN Kolf::Floater
 
 Kolf::Floater::Floater(QGraphicsItem* parent, b2World* world)
-	: Kolf::RectangleItem(QLatin1String("floater"), parent, world)
+	: Kolf::RectangleItem(QStringLiteral("floater"), parent, world)
 	, m_motionLine(QLineF(200, 200, 100, 100))
 	, m_speed(0)
 	, m_velocity(0)
@@ -622,8 +624,8 @@ Kolf::FloaterOverlay::FloaterOverlay(Kolf::Floater* floater)
 {
 	addHandle(m_handle1);
 	addHandle(m_handle2);
-	connect(m_handle1, SIGNAL(moveRequest(QPointF)), this, SLOT(moveMotionLineHandle(QPointF)));
-	connect(m_handle2, SIGNAL(moveRequest(QPointF)), this, SLOT(moveMotionLineHandle(QPointF)));
+	connect(m_handle1, &Kolf::OverlayHandle::moveRequest, this, &Kolf::FloaterOverlay::moveMotionLineHandle);
+	connect(m_handle2, &Kolf::OverlayHandle::moveRequest, this, &Kolf::FloaterOverlay::moveMotionLineHandle);
 	addHandle(m_motionLineItem);
 	QPen pen = m_motionLineItem->pen();
 	pen.setStyle(Qt::DashLine);
@@ -671,7 +673,7 @@ void Kolf::FloaterOverlay::moveMotionLineHandle(const QPointF& handleScenePos)
 //BEGIN Kolf::Sign
 
 Kolf::Sign::Sign(QGraphicsItem* parent, b2World* world)
-	: Kolf::RectangleItem(QLatin1String("sign"), parent, world)
+	: Kolf::RectangleItem(QStringLiteral("sign"), parent, world)
 	, m_text(i18n("New Text"))
 	, m_textItem(new QGraphicsTextItem(m_text, this))
 {
@@ -719,7 +721,7 @@ void Kolf::Sign::save(KConfigGroup* group)
 //BEGIN Kolf::Windmill
 
 Kolf::Windmill::Windmill(QGraphicsItem* parent, b2World* world)
-	: Kolf::RectangleItem(QLatin1String("windmill"), parent, world)
+	: Kolf::RectangleItem(QStringLiteral("windmill"), parent, world)
 	  , m_leftWall(new Kolf::Wall(parent, world))
 	  , m_rightWall(new Kolf::Wall(parent, world))
 	  , m_guardWall(new Kolf::Wall(parent, world))
